package com.mdd.admin.controller.log;

import com.mdd.admin.aop.Log;
import com.mdd.admin.service.IFloodLogService;
import com.mdd.admin.validate.commons.IdValidate;
import com.mdd.admin.validate.commons.PageValidate;
import com.mdd.admin.validate.log.FloodLogCreateValidate;
import com.mdd.admin.validate.log.FloodLogSearchValidate;
import com.mdd.admin.validate.log.FloodLogUpdateValidate;
import com.mdd.admin.vo.FloodLogDetailVo;
import com.mdd.admin.vo.FloodLogListedVo;
import com.mdd.common.aop.NotPower;
import com.mdd.common.core.AjaxResult;
import com.mdd.common.core.PageResult;
import com.mdd.common.validator.annotation.IDMust;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import javax.annotation.Resource;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

@RestController
@RequestMapping({"api/log"})
@Api(
   tags = {"防红记录管理"}
)
public class FloodLogController {
   @Resource
   IFloodLogService iFloodLogService;

   @NotPower
   @GetMapping({"/list"})
   @ApiOperation("防红记录列表")
   public AjaxResult<PageResult<FloodLogListedVo>> list(@Validated PageValidate pageValidate, @Validated FloodLogSearchValidate searchValidate) {
      PageResult<FloodLogListedVo> list = this.iFloodLogService.list(pageValidate, searchValidate);
      return AjaxResult.success(list);
   }

   @NotPower
   @GetMapping({"/detail"})
   @ApiOperation("防红记录详情")
   public AjaxResult<FloodLogDetailVo> detail(@Validated @IDMust @RequestParam("id") Integer id) {
      FloodLogDetailVo detail = this.iFloodLogService.detail(id);
      return AjaxResult.success(detail);
   }

   @NotPower
   @Log(
      title = "防红记录新增"
   )
   @PostMapping({"/add"})
   @ApiOperation("防红记录新增")
   public AjaxResult<Object> add(@Validated @RequestBody FloodLogCreateValidate createValidate) {
      this.iFloodLogService.add(createValidate);
      return AjaxResult.success();
   }

   @NotPower
   @Log(
      title = "防红记录编辑"
   )
   @PostMapping({"/edit"})
   @ApiOperation("防红记录编辑")
   public AjaxResult<Object> edit(@Validated @RequestBody FloodLogUpdateValidate updateValidate) {
      this.iFloodLogService.edit(updateValidate);
      return AjaxResult.success();
   }

   @Log(
      title = "防红记录删除"
   )
   @PostMapping({"/del"})
   @ApiOperation("防红记录删除")
   public AjaxResult<Object> del(@Validated @RequestBody IdValidate idValidate) {
      this.iFloodLogService.del(idValidate.getId());
      return AjaxResult.success();
   }

   @Log(
      title = "删除所有防红记录"
   )
   @PostMapping({"/delAll"})
   @ApiOperation("删除所有防红记录")
   public AjaxResult<Object> delAll() {
      this.iFloodLogService.delAll();
      return AjaxResult.success();
   }
}
